@@ -1,11 +1,12 @@
-id <- function(y, x, P, G, G.obs, v, to, tree) {
+id <- function(y, x, P, G, G.obs, v, topo, tree) {
+  to <- NULL
   if (length(P$var) == 0 & !(P$product | P$fraction)) tree$call <- list(y = y, x = x, P = probability(var = v), G = G, line = "", v = v)
   else tree$call <- list(y = y, x = x, P = P, G = G, line = "", v = v)
 
   # line 1
   if (length(x) == 0) {
     if (P$product | P$fraction) {
-      P$sumset <- union(setdiff(v, y), P$sumset) %ts% to
+      P$sumset <- union(setdiff(v, y), P$sumset) %ts% topo
       # P <- simplify.expression(P, NULL)
     } else {
       P$var <- y
@@ -15,19 +16,19 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
     return(list(P = P, tree = tree))
   }
 
-  an <- ancestors(y, G.obs, to)
+  an <- ancestors(y, G.obs, topo)
 
   # line 2
   if (length(setdiff(v, an)) != 0) {
     G.an <- induced.subgraph(G, an)
     G.an.obs <- observed.graph(G.an)
     if (P$product | P$fraction) {
-      P$sumset <- union(setdiff(v, an), P$sumset) %ts% to
+      P$sumset <- union(setdiff(v, an), P$sumset) %ts% topo
       # P <- simplify.expression(P, NULL)
     } else {
       P$var <- an
     }
-    nxt <- id(y, intersect(x, an), P, G.an, G.an.obs, an, to, list())
+    nxt <- id(y, intersect(x, an), P, G.an, G.an.obs, an, topo, list())
     tree$branch[[1]] <- nxt$tree
     tree$call$line <- 2
     tree$call$an <- an
@@ -36,19 +37,19 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
 
   # line 3
   G.xbar <- subgraph.edges(G, E(G)[!to(x)], delete.vertices = FALSE)
-  an.xbar <- ancestors(y, observed.graph(G.xbar), to)
+  an.xbar <- ancestors(y, observed.graph(G.xbar), topo)
   w <- setdiff(setdiff(v, x), an.xbar)
   w.len <- length(w)
   if (w.len != 0) {
-    co <- connected(w, y, G.xbar, to)
+    co <- connected(w, y, G.xbar, topo)
     if (length(co) < w.len) {
       v.new <- setdiff(v, setdiff(w, co))
       G <- induced.subgraph(G, v.new)
       G.obs <- observed.graph(G)
       v <- v.new
     }
-    nxt <- id(y, union(x, co) %ts% to, P, G, G.obs, v, to, list())
-    # nxt <- id(y, union(x, w), P, G, to, list())
+    nxt <- id(y, union(x, co) %ts% topo, P, G, G.obs, v, topo, list())
+    # nxt <- id(y, union(x, w), P, G, topo, list())
     tree$branch[[1]] <- nxt$tree
     tree$call$line <- 3
     tree$call$w <- w
@@ -58,11 +59,11 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
 
   # line 4
   G.remove.x <- induced.subgraph(G, v[!(v %in% x)])
-  s <- c.components(G.remove.x, to)
+  s <- c.components(G.remove.x, topo)
   if (length(s) > 1) {
     tree$call$line <- 4
     nxt <- lapply(s, function(t) {
-      return(id(t, setdiff(v, t), P, G, G.obs, v, to, list()))
+      return(id(t, setdiff(v, t), P, G, G.obs, v, topo, list()))
     })
     product.list <- lapply(nxt, "[[", "P")
     tree$branch <- lapply(nxt, "[[", "tree")
@@ -74,7 +75,7 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
     s <- s[[1]]
 
     # line 5 
-    cc <- c.components(G, to)
+    cc <- c.components(G, topo)
     if (identical(cc[[1]], v)) {
       v.string <- paste(v, sep = "", collapse = ",")
       s.string <- paste(s, sep = "", collapse = ",")
@@ -92,10 +93,10 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
       product.list <- vector(mode = "list", length = s.len)
       P.prod <- probability()
       for (i in s.len:1) {
-        # cond.set <- causal.parents(s[i], v[1:ind[i]], G, G.obs, to)
+        # cond.set <- causal.parents(s[i], v[1:ind[i]], G, G.obs, topo)
         cond.set <- v[0:(ind[i]-1)]
         if (P$product) {
-          P.prod <- parse.joint(P, s[i], cond.set, v, to)
+          P.prod <- parse.joint(P, s[i], cond.set, v, topo)
           # P.prod <- simplify.expression(P.prod, NULL)
         } else {
           P.prod <- P
@@ -111,7 +112,7 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
         return(list(P = P.new, tree = tree))
       } 
       if (P.prod$product | P.prod$fraction) {
-        P.prod$sumset <- union(P.prod$sumset, setdiff(s, y)) %ts% to
+        P.prod$sumset <- union(P.prod$sumset, setdiff(s, y)) %ts% topo
         # P.prod <- simplify.expression(P.prod, NULL)
       } else {
         P.prod$var <- setdiff(P.prod$var, union(P.prod$sumset, setdiff(s, y)))
@@ -126,22 +127,27 @@ id <- function(y, x, P, G, G.obs, v, to, tree) {
     tree$call$line <- 7
     tree$call$s.prime <- s
     s.len <- length(s)
-    product.list <- vector(mode = "list", length = s.len)
     ind <- which(v %in% s)
     G.s <- induced.subgraph(G, s)
     G.s.obs <- observed.graph(G.s)
+    product.list <- vector(mode = "list", length = s.len)
+    P.prod <- probability()
     for (i in s.len:1) {
-      # cond.set <- causal.parents(s[i], v[1:ind[i]], G, G.obs, to)
+      # cond.set <- causal.parents(s[i], v[1:ind[i]], G, G.obs, topo)
       cond.set <- v[0:(ind[i]-1)]
-      P.prod <- P
-      P.prod$var <- s[i]
-      P.prod$cond <- cond.set
+      if (P$product) {
+        P.prod <- parse.joint(P, s[i], cond.set, v, topo)
+      } else {
+        P.prod <- P
+        P.prod$var <- s[i]
+        P.prod$cond <- cond.set
+      }
       product.list[[s.len - i + 1]] <- P.prod
     }
     x.new <- intersect(x, s)
     nxt <- NULL
-    if (s.len > 1) nxt <- id(y, x.new, probability(product = TRUE, children = product.list), G.s, G.s.obs, s, to, list())
-    else nxt <- id(y, x.new, product.list[[1]], G.s, G.s.obs, s, to, list())
+    if (s.len > 1) nxt <- id(y, x.new, probability(product = TRUE, children = product.list), G.s, G.s.obs, s, topo, list())
+    else nxt <- id(y, x.new, product.list[[1]], G.s, G.s.obs, s, topo, list())
     tree$branch[[1]] <- nxt$tree
     return(list(P = nxt$P, tree = tree))
   }
