@@ -1,15 +1,16 @@
-trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
+trmz <- function(y, x, P, J, domain, w.index, D, Z, topo, tree) {
+  to <- NULL
   d <- length(D)
   v.s <- lapply(D, function(x) get.vertex.attribute(x, "name"))
   s <- lapply(1:d, function(x) v.s[[x]][which(vertex.attributes(D[[x]])$description == "S")])
-  s <- lapply(1:d, function(x) to[[x]][which(to[[x]] %in% s[[x]])])
+  s <- lapply(1:d, function(x) topo[[x]][which(topo[[x]] %in% s[[x]])])
   D.causal <- D[[1]]
   v <- get.vertex.attribute(D.causal, "name")
-  v <- to[[1]][which(to[[1]] %in% v)]
+  v <- topo[[1]][which(topo[[1]] %in% v)]
   D.obs <- observed.graph(D.causal)
   D.s.obs <- lapply(D, function(x) observed.graph(x))
-  anc <- ancestors(y, D.obs, to[[1]])
-  anc.s <- lapply(1:d, function(x) ancestors(y, D.s.obs[[x]], to[[x]]))
+  anc <- ancestors(y, D.obs, topo[[1]])
+  anc.s <- lapply(1:d, function(x) ancestors(y, D.s.obs[[x]], topo[[x]]))
   G.export <- D[[domain]]
   if (length(P$var) == 0 & !P$product & !P$fraction) tree$call <- list(y = y, x = x, P = probability(var = v, domain = domain),
     I = J, S = domain-1, G = G.export, line = "", v = v, Z = Z)
@@ -37,7 +38,7 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
     } else {
       P$var <- anc
     }
-    nxt <- trmz(y, intersect(x, anc), P, J, domain, w.index, anc.graph, Z, to, list())
+    nxt <- trmz(y, intersect(x, anc), P, J, domain, w.index, anc.graph, Z, topo, list())
     tree$branch[[1]] <- nxt$tree
     tree$call$line <- 2
     tree$call$anc <- anc
@@ -46,10 +47,10 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
 
   # line 3
   D.x.overbar <- subgraph.edges(D.causal, E(D.causal)[!to(x)], delete.vertices = FALSE)
-  anc.xbar <- ancestors(y, observed.graph(D.x.overbar), to[[1]])
+  anc.xbar <- ancestors(y, observed.graph(D.x.overbar), topo[[1]])
   w <- setdiff(setdiff(v, x), anc.xbar)
   if (length(w) != 0) {
-    nxt <- trmz(y, union(x, w), P, J, domain, w.index, D, Z, to, list())
+    nxt <- trmz(y, union(x, w), P, J, domain, w.index, D, Z, topo, list())
     tree$branch[[1]] <- nxt$tree
     tree$call$line <- 3
     tree$call$w <- w
@@ -59,15 +60,15 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
 
   # line 4
   D.remove.x <- induced.subgraph(D.causal, v[!(v %in% x)])
-  cc <- c.components(D.remove.x, to[[1]])
+  cc <- c.components(D.remove.x, topo[[1]])
   cc.len <- length(cc)
   if (cc.len > 1) {
     tree$call$line <- 4
     product.list <- vector(mode = "list", length = cc.len)
     nxt.list <- vector(mode = "list", length = cc.len)
     for (i in 1:cc.len) {
-      if (i == 1) nxt.list[[1]] <- trmz(cc[[1]], setdiff(v, cc[[1]]), P, J, domain, w.index, D, Z, to, list())
-      else nxt.list[[i]] <- trmz(cc[[i]], setdiff(v, cc[[i]]), P, J, domain, nxt.list[[i-1]]$W, D, Z, to, list())
+      if (i == 1) nxt.list[[1]] <- trmz(cc[[1]], setdiff(v, cc[[1]]), P, J, domain, w.index, D, Z, topo, list())
+      else nxt.list[[i]] <- trmz(cc[[i]], setdiff(v, cc[[i]]), P, J, domain, nxt.list[[i-1]]$W, D, Z, topo, list())
       product.list[[i]] <- nxt.list[[i]]$P
       tree$branch[[i]] <- nxt.list[[i]]$tree
     }
@@ -81,7 +82,7 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
   # line 5
   else {
     cc <- cc[[1]]
-    cG.s <- lapply(1:d, function(x) sc.components(D[[x]], to[[x]]))
+    cG.s <- lapply(1:d, function(x) sc.components(D[[x]], topo[[x]]))
     cG <- cG.s[[1]]
 
     # line 6
@@ -138,7 +139,7 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
         for (i in 1:cc.len) { 
           kappa <- union(kappa, setdiff(v[0:(ind[i]-1)], cc))
           if (P$product) {
-            P.prod <- parse.joint(P, cc[i], union(intersect(v[0:(ind[i]-1)], cc), kappa), v, to)
+            P.prod <- parse.joint(P, cc[i], union(intersect(v[0:(ind[i]-1)], cc), kappa), v, topo)
             P.prod <- simplify.expression(P.prod, NULL)
             product.list[[cc.len - i + 1]] <- P.prod
           } else {
@@ -148,22 +149,22 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
             product.list[[cc.len - i + 1]] <- P.prod
           }
         }
-        nxt <- trmz(y, intersect(x, cc), probability(product = TRUE, children = product.list), J, domain, w.index, cc.graph, Z, to, list())
+        nxt <- trmz(y, intersect(x, cc), probability(product = TRUE, children = product.list), J, domain, w.index, cc.graph, Z, topo, list())
         tree$branch[[1]] <- nxt$tree
         return(list(P = nxt$P, W = nxt$W, tree = tree))
       } else {
         kappa <- setdiff(v[0:(ind[1]-1)], cc)
         if (P$product) {
-          P.prod <- parse.joint(P, cc[i], union(intersect(v[0:(ind[i]-1)], cc), kappa) , v, to)
+          P.prod <- parse.joint(P, cc[i], union(intersect(v[0:(ind[i]-1)], cc), kappa) , v, topo)
           P.prod <- simplify.expression(P.prod, NULL)
-          nxt <- trmz(y, intersect(x, cc), P.prod, J, domain, w.index, cc.graph, Z, to, list())
+          nxt <- trmz(y, intersect(x, cc), P.prod, J, domain, w.index, cc.graph, Z, topo, list())
           tree$branch[[1]] <- nxt$tree
           return(list(P = nxt$P, W = nxt$W, tree = tree))
         } else {
           P.prod <- P
           P.prod$var <- cc[1]
           P.prod$cond <- union(intersect(v[0:(ind[1]-1)], cc), kappa) 
-          nxt <- trmz(y, intersect(x, cc), P.prod, J, domain, w.index, cc.graph, Z, to, list())
+          nxt <- trmz(y, intersect(x, cc), P.prod, J, domain, w.index, cc.graph, Z, topo, list())
           tree$branch[[1]] <- nxt$tree
           return(list(P = nxt$P, W = nxt$W, tree = tree))
         }
@@ -187,7 +188,7 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, to, tree) {
             ind <- ind + 1
             xcapz <- intersect(Z[[i]], x)
             D.remove.xcapz <- lapply(1:d, function(x) induced.subgraph(D[[x]], v[!(v %in% xcapz)]))
-            nxt <- trmz(y, setdiff(x, Z[[i]]), P, xcapz, i, W.new, D.remove.xcapz, Z, to, list())
+            nxt <- trmz(y, setdiff(x, Z[[i]]), P, xcapz, i, W.new, D.remove.xcapz, Z, topo, list())
             tree$branch[[ind]] <- nxt$tree
             E.new <- nxt$P
             W.new <- nxt$W
